@@ -2,147 +2,69 @@ package Sub::Genius;
 
 use strict;
 use warnings;
+use feature 'state';
 use FLAT::PFA;
 use FLAT::Regex::WithExtraOps;
-use Digest::MD5 ();
-use Storable    ();
-use Cwd         ();
 
-our $VERSION = q{0.13.01};
+our $VERSION = q{0.08};
 
 # constructor
 sub new {
     my $pkg  = shift;
     my %self = @_;
-    my $self = \%self;
+    my $self = \%self; 
     bless $self, $pkg;
-    die qq{'preplan' parameter required!\n} if not defined $self->{preplan};
+    die qq{'pre' parameter required!\n} if not defined $self->{preplan};
 
-    # set to undef to disable preprocessing
-    if ( not exists $self->{preprocess} ) {
-        $self->{preprocess} = 1;
-    }
-
-    # set to undef to disable caching
-    if ( not exists $self->{cachedir} ) {
-        $self->cachedir( sprintf( qq{%s/%s}, Cwd::cwd(), q{_Sub::Genius} ) );
-    }
-
-    # keep a historical record
-    $self->original_preplan($self->preplan);
-
-    # 'pre-process' plan - this step maximizes the chance of capturing
-    # the same checksum for identical PREs that may just be formatted differently
+    $self->{preprocess} = 1 if not exists $self->{preprocess};
+    # 'pre-process' plan 
     if ( $self->{preprocess} ) {
-        $self->_trim;
-        $self->_balkanize;
-        $self->_normalize;
+      $self->{preplan} = $self->_trim;
+      $self->{preplan} = $self->_balkanize;
     }
-
-    # generates checksum based on post-preprocessed form
-    $self->checksum( Digest::MD5::md5_hex( $self->preplan ) );
-
-    $self->pregex( FLAT::Regex::WithExtraOps->new( $self->preplan ) );
+    $self->{_regex} = FLAT::Regex::WithExtraOps->new( $self->{preplan} );
     return $self;
 }
 
-sub cachefile {
-    my $self = shift;
-    return ( $self->cachedir ) ? sprintf( qq{%s/%s}, $self->cachedir, $self->checksum ) : undef;
-}
-
-sub cachedir {
-    my ( $self, $dir ) = @_;
-    if ($dir) {
-        $self->{cachedir} = $dir;
-        if ( not -d $self->{cachedir} ) {
-            mkdir $self->{cachedir}, 0700 || die $!;
-        }
-    }
-    return $self->{cachedir};
-}
-
-sub checksum {
-    my ( $self, $sum ) = @_;
-    if ($sum) {
-        $self->{checksum} = $sum;
-    }
-    return $self->{checksum};
-}
-
-sub do_cache {
-    my $self = shift;
-    return ( $self->cachedir and $self->checksum and $self->cachefile );
-}
-
 # strips comments and empty lines
 sub _trim {
-    my $self = shift;
-    my $_pre = q{};
-    my @pre  = ();
+  my $self = shift;
+  my $_pre = q{};
+  my @pre  = ();
   STRIP:
-    foreach my $line ( split /\n/, $self->{preplan} ) {
-        next STRIP if ( $line =~ m/^\s*#|^\s*$/ );
-        my @line = split /\s*#/, $line;
-        push @pre, $line[0];
-    }
-    $self->preplan( join qq{\n}, @pre );
-    return $self->preplan;
+  foreach my $line (split /\n/, $self->{preplan}) {
+    next STRIP if ($line =~ m/^\s*#|^\s*$/); 
+    my @line = split /\s*#/, $line;
+    push @pre, $line[0];
+  }
+  return join qq{\n}, @pre;
 }
 
 sub _balkanize {
-    my $self = shift;
-    if ( $self->{preplan} =~ m/[#\[\]]+/ ) {
-        die qq{plan to be bracketized must not contain '#', '[', or ']'};
-    }
-    my $_pre = q{};
-    my @pre  = ();
+  my $self = shift;
+  if ($self->{preplan} =~ m/[#\[\]]+/) {
+    die qq{plan to be bracketized must not contain '#', '[', or ']'};
+  }
+  my $_pre = q{};
+  my @pre  = ();
   STRIP:
-    foreach my $line ( split /\n/, $self->{preplan} ) {
-
-        # supports strings with namespace delim, '::'
-        $line =~ s/([a-zA-Z:_\d]+)/\[$1\]/g;
-        push @pre, $line;
-    }
-    $self->preplan( join qq{\n}, @pre );
-    return $self->preplan;
+  foreach my $line (split /\n/, $self->{preplan}) {
+    $line =~ s/([a-zA-Z]+)/\[$1\]/g;
+    push @pre, $line;
+  }
+  return join qq{\n}, @pre;
 }
 
-# currently, removes all spaces and newlines
-sub _normalize {
-    my $self     = shift;
-    my @pre      = split /\n/, $self->{preplan};
-    my $minified = join qq{}, @pre;
-    $minified =~ s/[\s]+//g;
-    $self->preplan($minified);
-    return $self->preplan;
-}
-
-# accessor for original plan
-sub original_preplan {
-    my ( $self, $pp ) = @_;
-    if ($pp) {
-        $self->{original_preplan} = $pp;
-    }
-    return $self->{original_preplan};
-}
-
-# accessor for original plan
+# RO accessor for original plan 
 sub preplan {
-    my ( $self, $pp ) = @_;
-    if ($pp) {
-        $self->{preplan} = $pp;
-    }
+    my $self = shift;
     return $self->{preplan};
 }
 
-# accessor for original
-sub pregex {
-    my ( $self, $pregex ) = @_;
-    if ($pregex) {
-        $self->{pregex} = $pregex;
-    }
-    return $self->{pregex};
+# RO accessor for original
+sub _regex {
+    my $self = shift;
+    return $self->{_regex};
 }
 
 # set/updated whenever ->next() and friends are called, simple way to
@@ -152,74 +74,47 @@ sub plan {
     return $self->{plan};
 }
 
-# setter/getter for DFA
-sub dfa {
-    my ( $self, $dfa ) = @_;
-    if ($dfa) {
-        $self->{DFA} = $dfa;
-    }
-    return $self->{DFA};
-}
-
 # Converts plan -> PFA -> NFA -> DFA:
 # NOTE: plan is not generated here, much call ->next()
+#  use param, 'mindfa=>1' to use minimal DFA 
 #  can pass param to underlying ->dfa also, like 'reset => 1'
 sub init_plan {
-    my ( $self, %opts ) = @_;
+    my ($self, %opts) = @_;
 
     # requires plan (duh)
-    die qq{Need to call 'new' with 'preplan => q{PRE...}' to initialize\n} if not $self->pregex;
-
-    # convert PRE to DFA
-    $self->convert_pregex_to_dfa(%opts);
+    die qq{Need to call 'new' to initialize\n} if not $self->{_regex};
 
     # warn if DFA is not acyclic (infinite strings accepted)
-    if ( $self->dfa->is_infinite ) {
-        if ( not $self->{'allow-infinite'} ) {
-            warn qq{(fatal) Infinite language detected. To avoid, do not use Kleene Star (*).\n};
-            die qq{  pass in 'allow-infinite => 1' to constructor to disable this warning.\n};
-        }
+    if ( $self->dfa(%opts)->is_infinite and not $self->{'allow-infinite'} ) {
+        warn qq{(warn) Infinite language detected. To avoid, do not use Kleene Star (*).\n};
+        warn qq{ Pass 'allow-infinite => 1' to constructor to disable this warning\.\n};
     }
 
-    # else - currently no meaningful way to control 'infinite' languages, this needs to
-    # be investigated
-
     # returns $self, for chaining in __PACKAGE__->run_any
     return $self;
 }
 
 # to force a reset, pass in, C<reset => 1>.; this makes a lot of cool things
-sub convert_pregex_to_dfa {
+sub dfa {
     my ( $self, %opts ) = @_;
-
-    # look for cached DFA
-    if ( not $self->{reset} and $self->do_cache ) {
-        if ( -e $self->cachefile ) {
-            $self->dfa( Storable::retrieve( $self->cachefile ) );
-            return $self->dfa;
+    if ( not defined $self->{DFA} or defined $opts{reset} ) {
+        $self->{DFA} = $self->{_regex}->as_pfa->as_nfa->as_dfa;
+        if (not defined $opts{'mindfa'}) {
+          $self->{DFA} = $self->{_regex}->as_pfa->as_nfa->as_dfa->trim_sinks;
+        }
+        else {
+          $self->{DFA} = $self->{_regex}->as_pfa->as_nfa->as_dfa->as_min_dfa->trim_sinks;
         }
     }
-
-    if ( not $self->dfa or defined $opts{reset} ) {
-        $self->dfa( $self->pregex->as_pfa->as_nfa->as_dfa->as_min_dfa->trim_sinks );
-
-        # save to cache
-        if ( $self->do_cache ) {
-            Storable::store( $self->dfa, $self->cachefile );
-        }
-    }
-    return $self->dfa;
+    return $self->{DFA};
 }
 
 # Acyclic String Iterator
 #   force a reset, pass in, C<reset => 1>.
 sub next {
     my ( $self, %opts ) = @_;
-
-    die qq{(fatal) Use 'inext' instead of 'next' for infinite languages.\n} if $self->dfa->is_infinite;
-
     if ( not defined $self->{_acyclical_iterator} or $opts{reset} ) {
-        $self->{_acyclical_iterator} = $self->dfa->init_acyclic_iterator(q{ });
+        $self->{_acyclical_iterator} = $self->{DFA}->init_acyclic_iterator(q{ });
     }
 
     $self->{plan} = $self->{_acyclical_iterator}->();
@@ -248,29 +143,15 @@ sub run_any {
 
 # Runs any single serialization ONCE
 # defaults to main::, specify namespace of $sub
-#
-# * ns      => q{Some::NS}  # specify name space
-# * scope   => { }          # specify initial state of pipeline accumulator
-# * verbose => 0|1          # output runtime diagnostics
+# with
+# * ns => q{Some::NS}    # specify name space
+# * scope => { }         # specify initial state of pipeline accumulator
+# * verbose => 0|1       # output runtime diagnostics
 sub run_once {
     my ( $self, %opts ) = @_;
-
-    # initialize scope
+    $opts{ns}    //= q{main};
     $opts{scope} //= {};
-
-    # appends '::' (no check if '::' is at the end to encourage a standard idiom)
-    if ( not defined $opts{ns} ) {
-        $opts{ns} = q{main::};
-    }
-    else {
-        $opts{ns} .= q{::};
-    }
-
-    # only call interator if $self->{plan} has not yet been set
-    $self->next if not $self->plan;
-
-    # check plan is set, just to be sure
-    if ( my $preplan = $self->plan ) {
+    if ( my $preplan = $self->next() ) {
         if ( $opts{verbose} ) {
             print qq{plan: "$preplan" <<<\n\nExecute:\n\n};
         }
@@ -279,39 +160,13 @@ sub run_once {
         # main run loop - run once
         local $@;
         foreach my $sub (@seq) {
-            eval sprintf( qq{%s%s(\$opts{scope});}, $opts{ns}, $sub );
+            eval sprintf( qq{%s::%s(\$opts{scope});}, $opts{ns}, $sub );
             die $@ if $@;    # be nice and die for easier debuggering
         }
     }
     return $opts{scope};
 }
 
-#
-# D R A G O N S
-#            ~~~> *E X P E R I M E N T A L* (not even in POD yet)
-#
-
-# Deep (Infinite) String Iterator
-#   force a reset, pass in, C<reset => 1>.
-#
-# To us:
-#   my $sq = Sub::Genius=->new(preplan => q{a&b*c}, => 'allow-infinite' => 1);
-#   $sq->init_plan;
-#
-#
-sub inext {
-    my ( $self, %opts ) = @_;
-    local $| = 1;
-    $opts{max} //= 5;
-    if ( not defined $self->{_deepdft_iterator} or $opts{reset} ) {
-        $self->{_deepdft_iterator} = $self->dfa->init_deepdft_iterator( $opts{max}, q{ } );
-    }
-
-    $self->{plan} = $self->{_deepdft_iterator}->();
-
-    return $self->{plan};
-}
-
 1;
 
 __END__
@@ -342,29 +197,22 @@ let's do it correctly. C<:)>
 
 =head1 SYNOPSIS
 
-    # D E F I N E  T H E  P L A N
     my $preplan = q{( A B )  &   ( C D )      (Z)};
-    #                 \ /          \ /         |
-    #>>>>>>>>>>>     (L1) <shuff>  (L2) <cat>  L3
-     
-    # C O N V E R T  T H E  P L A N  T O  D F A 
-    my $sq = Sub::Genius->new(preplan => $preplan);
+    #             \ /          \ /         |
+    #>>>>>>>>>>> (L1) <shuff>  (L2) <cat>  L3
 
-    # I N I T  T H E  P L A N
-    $sq->init_plan;
-     
-    # R U N  T H E  P L A N
-    $sq->run_once;
+    my $sq = Sub::Genius->new(preplan => $preplan);
+    $sq->run_once();
     print qq{\n};
-    
+
     # NOTE: sub declaration order has no bearing on anything
-     
+    
     sub A { print qq{A}  } #-\
     sub B { print qq{B}  } #--- Language 1
-     
+                            
     sub C { print qq{C}  } #-\
     sub D { print qq{D}  } #--- Language 2
-     
+                            
     sub Z { print qq{\n} } #--- Language 3
 
 The following expecity execution of the defined subroutines are all
@@ -391,34 +239,25 @@ expressing the following constraints:
 
 =over 4
 
-=item C<sub A>
+=item C<sub A> must run before C<sub B>
 
-I<must> run before C<sub B>
+=item C<sub C> must run before C<sub D>
 
-=item C<sub C>
-
-I<must> run before C<sub D>
-
-=item C<sub Z>
-
-is I<always> called last
+=item C<sub Z> is always called last
 
 =back
 
+=head2 Meaningful Subroutine Names C<FLAT> allows single character symbols
+to be expressed with out any decorations;
 
-=head2 Meaningful Subroutine Names
-
-C<FLAT> allows single character symbols to be expressed with out any
-decorations;
-
-    my $preplan = q{ s ( A (a b) C & ( D E F ) ) f };  # define plan
-    my $sq = Sub::Genius->new(preplan => $preplan);    # convert plan
+    my $preplan = q{ s ( A (a b) C & ( D E F ) ) f };
+    my $sq = Sub::Genius->new(preplan => $preplan);
 
 The I<concatentation> of single symbols is implied, and spaces between
 symbols doesn't even matter. The following is equivalent to the PRE above,
 
-    my $preplan = q{s(A(ab)C&(DEF))f};                 # define plan
-    my $sq = Sub::Genius->new(preplan => $preplan);    # convert plan
+    my $preplan = q{s(A(ab)C&(DEF))f}; my $sq = Sub::Genius->new(preplan =>
+    $preplan);
 
 It's important to note immediately after the above example, that the PRE
 may contain C<symbols> that are made up of more than one character.
@@ -426,7 +265,6 @@ may contain C<symbols> that are made up of more than one character.
 But this is a mess, so we can use longer subroutine names as symbols and
 break it up in a more readable way:
 
-    # define plan
     my $preplan = q{
       start
         (
@@ -445,7 +283,7 @@ break it up in a more readable way:
         )
       fin
     };
-    # convert plan
+     
     my $sq = Sub::Genius->new(preplan => $preplan);
 
 This is much nicer and starting to look like a more natural expression
@@ -454,13 +292,11 @@ meaningful symbols.
 
 =head2 Inline Comments
 
-A final convenience provided during the preprocessing of PREs (which can
-be turned I<off> with C<< preprocess => 0 >> passed to C<new>), is the
-support of inline comments and empty lines.
+A final convenience provided during the preprocessing of PREs (which can be
+turned I<off>), is the support of inline comments and empty lines.
 
 For example,
 
-    # define plan
     my $preplan = q{
       start         # Language 1 (L1) always runs first
         (
@@ -479,9 +315,10 @@ For example,
         )
       fin           # Language 4 (L4) always runs last
     };
-    # convert plan
+    
     my $sq = Sub::Genius->new(preplan => $preplan);
 
+
 =head1 DESCRIPTION 
 
 L<Sub::Genius> generates a correctly ordered, sequential series of
@@ -502,7 +339,7 @@ subroutine A>.
 
    my $preplan = q{ A   B };
 
-Partially ordered means, I<subroutine A may lead or lag subroutine B, both
+Partially ordered means, I<subroutine B may lead or lag subroutine B, both
 must be executed>.
 
    my $preplan = q{ A & B };
@@ -588,10 +425,7 @@ from [2],
     the order specified by its program.
 
 And it is the C<shuffle> operator that provides the I<concurrent> semantics
-to be expressed rather I<naturally>, and in a way the human mind can understand.
-This, above all, is absolultely I<critical> for bridging the gap between the
-concurrent semantics people clamor for in I<Perl> and the inherent uniprocess
-environment presented in the C<perl> C<runtime>.
+to be expressed rather easily.
 
 =head2 Regular Language Operators
 
@@ -599,77 +433,60 @@ The following operator are available via C<FLAT>:
 
 =over 4
 
-=item I<concatentation>: C<L1 L2>
-
-there is no character for this, it is implied when two symbols are directly
-next to one another. E.g., C<a b c d>, which can also be expressed as
-C<abcd> or even C<[a][b][c][d]>.
+=item I<concatentation> - there is no character for this, it is implied when
+two symbols are directly next to one another. E.g., C<a b c d>, which can also
+be expressed as C<abcd> or even C<[a][b][c][d]>.
     
 =item examples,
 
-      my $preplan = q{  a        b        c   };       # single char symbol
-      my $preplan = q{symbol1 symbol2 symbol3 };       # multi-char symbol
+      my $preplan = q{  a        b        c   };            # single char symbol
+      my $preplan = q{symbol1 symbol2 symbol3 };            # multi-char symbol
 
-=item C<|> - I<union>: C<L1 | L2>
-
-If it looks like an C<or>, that is because it is. E.g., C<a|b|c|d> means
-a valid string is, C<'a' or 'b' or 'c' or 'd'>. An I<or> is a union. In
-Regular Languages, it combines the valid set of strings from each I<or>'d
-language together. So the resulting language accepts all strings from I<L1>
-and all strings from I<L2>.
+=item C<|> - I<union> - represented as a pipe, C<|>. If it looks like an C<or>, that
+is because it is. E.g., C<a|b|c|d> means a valid string is, C<'a' or 'b' or 'c'
+or 'd'>.
 
 =item examples,
 
-      my $preplan = q{  a     |    b    |    c   };    # single char symbol
-      my $preplan = q{symbol1 | symbol2 | symbol3};    # multi-car symbol
+      my $preplan = q{  a     |    b    |    c   };         # single char symbol
+      my $preplan = q{symbol1 | symbol2 | symbol3};         # multi-car symbol
 
-=item C<&> - I<shuffle>: C<L1 & L2>
-
-It is the addition of this operator, which is I<closed> under Regular
-Languages, that allows concurrency to be expressed. It is also generates
-a I<Parallel Finite Automata>, which is an I<e-NFA> with an additional
-special transition, represented by L<lambda>. It's still closed under RLs,
-it's just a way to express a constraint on the NFA that preserves the
-total and partial ordering among shuffled languages. It is this property
-that leads to guaranteeing I<sequential consistency>.
+=item C<&> - I<shuffle> - represented by the ampersand, C<&>. It is the addition of this
+operator, which is I<closed> under Regular Languages, that allows concurrency to be expressed. It is also generates a I<Parallel Finite Automata>, which is an
+I<e-NFA> with an additional special transition, represented by L<lambda>. It's
+still closed under RLs, it's just a way to express a constraint on the NFA that
+preserves the total and partial ordering among shuffled languages. It is this
+property that leads to guaranteeing I<sequential consistency>.
 
 =item B<E.g.>,
 
-      my $preplan = q{   a    &    b    &    c   };    # single char symbol
-      my $preplan = q{symbol1 & symbol2 & symbol3};    # multi-car symbol
+      my $preplan = q{   a    &    b    &    c   };         # single char symbol
+      my $preplan = q{symbol1 & symbol2 & symbol3};         # multi-car symbol
 
-=item C<*> - I<Kleene Star>: C<L1*>
-
-Creates an I<infinite> language; accepts either nothing, or an infinitely
-repeating concatentation of valid strings accepted originally by I<L1>.
-
-L<Sub::Genius> currently will die if one attempts to use this, but it is
-supported just fine by C<FLAT>. It's not supported in this module because
-it admits an I<infinite> language. That's not to say it's not useful for
-towards the aims of this module; but it's not currently understood by
-the merely I<sub-genius> module author(s) how to leverage this operator.
+=item C<*> - I<Kleene Star> - L<Sub::Genius> currently will die if one attempts to use
+this, but it is supported just fine by C<FLAT>. It's not supported in this module
+because it admits an I<infinite> language. That's not to say it's not useful for
+towards the aims of this module; but it's not currently understood by the merely
+I<sub-genius> module author(s) how to leverage this operator.
 
 =item B<E.g.>,
 
       my $preplan = q{    a     &     b*     &   c};  # single char symbol
       my $preplan = q{symbol1 & symbol2* & symbol3};  # multi-car symbol
 
-B<Note>: the above PRE is not supported in L<Sub::Genius>, but may be in
-the future.  One may tell C<Sub::Genius> to not C<die> when an infinite
-language is detected by passing the C<infinite> flag in the constructor; but
-currently the behavior exhibited by this module is considered I<undefined>:
+=item Note: the above PRE is not supported in L<Sub::Genius>, but may be in the future.
+One may tell C<Sub::Genius> to not C<die> when an infinite language is detected
+by passing the C<infinite> flag in the constructor; but currently the behavior
+exhibited by this module is considered I<undefined>:
 
 =item B<E.g.>,
 
-      # single char symbol
-      my $preplan = q{    a     &     b*     &   c      };
-      
-      # without 'allow-infinite'=>1, C<new> will fail here
-      my $sq = Sub::Genius->new(preplan => $preplan, 'allow-infinite' => 1);
+      my $preplan = q{    a     &     b*     &   c      };                 # single char symbol
+      my $sq = Sub::Genius->new(preplan => $preplan, 'allow-infinite' => 1);  # without 'allow-infinite'=>1, C<new> will fail here
 
 =back
 
-=head2 Precedence Using Parentheses
+=head2 Precedence
 
 C<(>, C<)>
 
@@ -686,7 +503,6 @@ must be obeyed when serialized. The example is also nicely illustrative
 of the making a I<plan> more readable using comments (not to suggest an
 I<idiom> :)).
 
-    # define plan
     my $preplan = q{
       ##########################################################
       # Plan Summary:                                          #
@@ -740,20 +556,7 @@ PRE accepted by L<FLAT>.
 
 B<Optional pramameter:>
 
-=over 4
-
-=item C<< cachedir => $dir >>
-
-Sets default cache directory, which by default is C<$(pwd)/_Sub::Genius>.
-
-If set to C<undef>, caching is disabled.
-
-=item C<< preprocess => undef|0 >>
-
-Disables the current preprocessing, which strips comments and adds brackets
-to all I<words> in the PRE.
-
-=item C<< q{allow-infinite} => 1 >>
+C<< q{allow-infinite} => 1 >>
 
 Default is C<undef> (I<off>).
 
@@ -769,23 +572,6 @@ The reference, if captured by a scalar, can be wholly reset using the same
 parameters as C<new> but calling the C<plan_nein> methods. It's a minor
 convenience, but one all the same.
 
-=back
-
-=item C<cachedir>
-
-Accessor for obtaining the value of the cache directory, either the default
-value or as set via C<new>.
-
-=item C<checksum>
-
-Accessor for obtaining the MD5 checksum of the PRE, specified by using the
-C<preplan> parameter via C<new>.
-
-=item C<cachefile>
-
-Acessor for getting the full path of the cache file associated with the PRE;
-this file may or may not exist.
-
 =item C<init_plan>
 
 This takes the PRE provided in the C<new> constructure, and runs through
@@ -812,16 +598,6 @@ steps being implemented.
     
     $sq->init_plan;
 
-B<Note:> I<Caching>
-
-It is during this call that the DFA associated with the I<preplan> PRE is
-I<compiled> into a DFA. That also means, this is where cached DFAs are
-read in; or if not yet cached, are saved after the process to convert the
-PRE to a DFA.
-
-As is mentioned several times, caching may be disabled by passing the parameter,
-C<< cachedir => undef >> in the C<new> constructor.
-
 =item C<run_once>
 
 Returns C<scope> as affected by the assorted subroutines.
@@ -830,7 +606,7 @@ Accepts two parameters, both are optional:
 
 =over 4
 
-=item ns => q{My::Sequentially::Consistent::Methods}
+=item ns => q{My::CS::Oblivious::Funcs}
 
 Defaults to C<main::>, allows one to specify a namespace that points to a library
 of subroutines that are specially crafted to run in a I<sequentialized> environment.
@@ -863,21 +639,30 @@ returns:
 
 =item C<next>
 
-C<run_once> calls C<next> on C<$self> if it has not been run explicitly
-after C<init_plan>, but it will continue to call it if C<run_once> is
-run I<again>. This means that the C<preplan> will remain in place until
-C<next> is called once again.
+L<FLAT> provides some utility methods to pump FAs for valid strings;
+effectively, its the enumeration of paths that exist from an initial
+state to a final state. There is nothing magical here. The underlying
+method used to do this actually creates an interator.
+
+When C<next> is called the first time, an interator is created, and the
+first string is returned. There is currently no way to specify which
+string (or C<plan>) is returned first, which is why it is important that
+the concurrent semantics declared in the PRE are done in such a way that
+any valid string presented is considered to be sequentially consistent
+with the memory model used in the implementation of the subroutines. Perl
+provides the access to these memories by use of their lexical variable
+scoping (C<my>, C<local>) and the convenient way it allows one to make a
+subroutine maintain persistent memory (i.e., make it a coroutine) using
+the C<state> keyword. See more about C<PERL's UNIPROCESS MEMORY MODEL
+AND ITS EXECUTION ENVIRONMENT> in the section above of the same name.
 
 An example of iterating over all valid strings in a loop follows:
 
-    while (my $preplan = $sq->next) {
+    while (my $preplan = $sq->next_plan()) {
       print qq{Plan: $preplan\n};
       $sq->run_once;
     }
 
-Once the interator has generated I<all> valid strings, the loop above
-concludes.
-
 Note, in the above example, the concept of I<pipelining> is violated
 since the loop is running each plan ( with no guaranteed ordering ) in
 turn. C<$scope> is only meaningful within each execution context. Dealing
@@ -893,30 +678,9 @@ be captured during each iteration for future processessing:
     # now do something with all the final scopes collected
     # by @all_final_scopes
 
-There are also no deterministic guarantees of the ordering of valid
-strings (i.e., sequentially consistent execution plans).
-
-L<FLAT> provides some utility methods to pump FAs for valid strings;
-effectively, its the enumeration of paths that exist from an initial
-state to a final state. There is nothing magical here. The underlying
-method used to do this actually creates an interator.
-
-When C<next> is called the first time, an interator is created, and the
-first string is returned. There is currently no way to specify which
-string (or C<plan>) is returned first, which is why it is important that
-the concurrent semantics declared in the PRE are done in such a way that
-any valid string presented is considered to be sequentially consistent
-with the memory model used in the implementation of the subroutines.
-
-Perl provides the access to these memories by use of their lexical variable
-scoping (C<my>, C<local>) and the convenient way it allows one to make a
-subroutine maintain persistent memory (i.e., make it a coroutine) using
-the C<state> keyword. See more about C<PERL's UNIPROCESS MEMORY MODEL
-AND ITS EXECUTION ENVIRONMENT> in the section above of the same name.
-
-At this time C<Sub::Genius> only permits I<finite> languages by default,
-therefore there is always a finite list of accepted strings. The list
-may be long, but it's finite.
+At this time C<Sub::Genius> only permits I<finite> languages, therefore
+there is always a finite list of accepted strings. The list may be long, but
+it's finite.
 
 As an example, the following admits a large number of orderings in a realtively
 compact DFA, in fact there are 26! (factorial) such valid orderings:
@@ -963,204 +727,12 @@ and C<run_once>. It presents a simple one line interfaces:
 
 =item C<plan_nein>
 
-I<DEPRECATED> - this was a not a well thought out idea and will be removed
-in the very near term, if it does not remove itself first. C<< >:E >>
-
 Using an existing reference instantiation of C<Sub::Genius>, resets
 everything about the instance. It's effectively link calling C<new> on the
 instance without having to recapture it.
 
 =back
 
-=head1 PERFORMANCE CONSIDERATIONS
-
-L<FLAT> is very useful for fairly complex semantics, but the number of
-FA states grows extremely large as it moves from the non-deterministic
-realm to to the deterministic.
-
-What that means in most cases, is that the more non-deterministic the PRE
-(e.g., the more C<shuffles> or C<&>'s), the longer it will take for the
-final DFA to be created. It would not be hard to overwhelm a system's
-memory with a PRE like the one suggested above,
-
-    my $preplan = join(q{&},(a..z));
-
-This suggests all 26 letter combinations of all of the lower case letters
-of the alphabet (26! such combinations, as noted above) must be accounted
-for in the final minimized DFA, which is really just a large graph.
-
-The algorithms inplemented in L<FLAT> to convert from a PRE to a PFA
-(equivalent to a PetriNet) to a NFA to a DFA, and finally to a minimized
-DFA are the basic' ones discussed in any basic CS text book on automata,
-e.g., [5].
-
-To get around the potential for performance issues related to converting
-PREs to DFAs, there are two current approaches. The first and most obvious
-one is caching, discussed immediately in the following section. After this,
-the idea of I<lazy sequentilization> - or delaying the conversion of a
-PRE until the last possible moment - is introduced with a proof of concept
-example that works I<now>.
-
-=head1 CACHING 
-
-The practicality of converting the PRE to a DFA suitable for generating
-valid execution orders is reached relatively quickly as more C<shuffle>s
-are added.  For this reason, C<init_plan> looks for a cache file. If
-available, it's loaded saving potentally long start up times.
-
-=head2 How Caching Works in C<Sub::Genius>
-
-Caching of the PRE is done after it has been I<compiled> into a DFA, which
-is called most directly via C<init_plan>. Unless the constructor has been
-created specifically turning it off via C<cachedir=>undef>, L<Storable>'s
-C<store> method is used to save it to the C<cachedir>. Internally, a C<md5>
-checksum is generated using L<Digest::MD5>'s C<md5_hex> method on the PRE
-after it's been I<preprocessed>. If the constructor is passed the flag
-to disable preprocessing, the checksum is generated in consideration of
-the PRE as specified using the C<preplan> parameter of C<new>.
-
-The lifecycle of caching, assuming default behavior is:
-
-=over 4
-
-=item 1. constructor used to create instance with C<preplan> specified
-
-=item 2. C<preplan>
-
-is I<preprocessed> to strip comments, blank spaces, and put square braces
-around all I<words>
-
-=item 3. a checksum
-
-is generated using the value of post-preprocessed C<preplan> field
-
-=item 4. calling C<init_plan>
-
-first looks for a cached file representing the DFA's checksum; if found
-it C<retrieve>s this file and this is the DFA moving forward
-
-=item 5. if no such cached DFA exists
-
-then internally the L<FLAT> enabled process to convert a PRE to a DFA is
-invoked; this is the step that has the potential for taking an inordinate
-amount of time
-
-=item 6. the DFA is saved
-
-in C<cachedir> with the file name that matches the value of C<checksum>.
-
-=back
-
-=head2 Role of Checksumming and PRE Normalization
-
-The current implementation of the checksumming of PREs is done by
-normalizing the provide PRE during the I<preprocess> step. This includes:
-stripping comments, adding square backets (C<[]>) around all words
-(C<\w>) including single characters, eliminating all new lines, and
-finally eliminating all spaces. This effectively creates a minimized PRE
-that retains all Regular Expression operators, delimits all symbols by a
-circumfix square brace pair, eliminates all spaces, and eliminates all
-new lines. With this approach, caching is effective for all PREs that
-minimize to the same exact form regardless of any spacing or comments
-that might be present.
-
-=head2 Final Notes on Caching
-
-Caching for C<compiled> things, in lieu of better performance for
-necessarily complext algorithms, seems an acceptible cheat. Well known
-examples of this included L<Inline> (e.g., the C<_Inline> default directory)
-and the caching of rendered template by L<Template> Toolkit.
-
-This could be couched as a I<benefit>, but the truth is that it would be
-better if caching DFAs was not necessary. In the case for very complex
-or I<highly> shuffled PREs, it is necessary to precompile - and maybe
-even on much more performant machines than the one the code using them
-will run on. It may just be the nature of taming this beast.
-
-This also suggests I<best practices> if this module, or the approach it
-purports, ever reaches some degree of interesting. It is reasonable to
-imagine the rendering of I<frozen> DFAs (the I<compiled> form of PREs
-used to generate valid execution plans) is like a compilation step, just
-like building XS modules necessarily requires the compiling of code during
-module installation. It could also be, that assuming C<store>'d files are
-platform independent, that a repository of these can be mainted somewhere
-like in a git repo for distribution. Indeed, there could be entire modules
-on CPAN that provide libraries to DFAs that ensure sequential consistency
-for a large variety of applications.
-
-Until this is proven in the wild, it's just speculation. For now, it's
-sufficient to state that caching is a necessary part of this approach
-and may be for some time. The best we can do is provide a convenient
-way to handle it, and it's taking a hint from modules like C<Inline>
-that we start off on the right footing.
-
-As a final note, caching I<can> be disabled in the constructure,
-
-    my $sq = Sub::Genius->new( preplan => $preplan, cachedir => undef );
-
-=head1 LAZY OR NESTED LINEARIZATION
-
-This concept bears more exploration, but the idea is basically to encapsulate
-additional calls to C<Sub::Genious> inside of subroutines contained in higher
-level PREs. This kind of thing is done often, a good example is L<Web::Scraper>'s
-concept of nested scrapers.
-
-For example, all of the words in the following C<$preplan> simply represent
-calls to subroutines, albeit constrained to the orderings implied by the PRE
-operators present: 
-
-    my $preplan = q{
-      init
-      ( subA
-          &
-          (
-            subB
-       
-            _DO_LAZY_SEQ_   #<~ this subroutine encapsulates another PRE
-      
-            subC
-          )
-          &
-        subD
-      )
-      fin
-    };
-     
-    my $sq = Sub::Genius->new(preplan => $preplan)->init_plan;
-     
-    my $final_scope = $sq->run_any;
-     
-    sub _DO_LAZY_SEQ_ {
-      my $scope = shift;
-      my $inner_preplan = q{
-        subA
-          &
-        subB
-          &
-        subC
-          & 
-        subD
-          &
-        subE #<~ new to this PRE!
-      };
-      return Sub::Genius->new(preplan => $inner_preplan)->run_any;
-    }
-     
-    # new sub required to support the lazily linearized PRE
-    sub subE {
-      my $scope = shift;
-      print qq{Sneaky sneak subE says, "Hi!"\n};
-      return $scope;
-    }
-     
-    # ... assume all other subs are defined, we define _DO_LAZY_SEQ_ with
-    # its own $preplan;
-
-The above idea does work and benefits from caching as well as the top
-level. Future enhancements may provide some builtin I<lazy> enablement
-routines. But for now, it suffices to demonstrate that this is a viable
-approach.
-
 =head1 DEBUGGING AND TOOLS
 
 C<stubby>
@@ -1170,17 +742,6 @@ the time being it is located in the C<./bin> directory of the distribution
 and on Github. It will help anyone interested in getting an idea of what
 programming using this model is like.
 
-See L<stubby> for more information, but it currently allows for both stub
-code generation to get one started on using this module; and the ability
-to pre-cache (or I<compile>) PREs into the DFA needed to generate valid
-execution plans. It's the conversion from a PRE to this DFA that the most
-potentially expensive aspect of this approach.
-
-See L<stubby> for more information, but it currently allows for both stub
-code generation to get one started on using this module; and the ability
-to pre-cache (or I<compile>) PREs into the DFA needed to generate valid
-execution plans.
-
 C<fash>
 
 This tool is I<just> a C<bash> script that makes it easier to called L<FLAT>
@@ -1219,10 +780,30 @@ L<Sub::Genius>.
 
 L<stubby> and L<fash>.
 
+=head1 PERFORMANCE LIMITATIONS
+
+L<FLAT> is very useful for fairly complex semantics, but the number of
+FA states grows extremely large as it moves from the non-deterministic
+realm to to the deterministic. 
+
+What that means in most cases, is that the more non-deterministic the PRE
+(e.g., the more C<shuffles> or C<&>'s), the longer it will take for the final
+DFA to be created. It would not be hard to overwhelm a system's memory
+with a PRE like the one suggested above,
+
+    my $preplan = join(q{&},(a..z));
+
+This suggests all 26 letter combinations of all of the lower case letters of
+the alphabet (26! such combinations, as noted above) must be accounted for
+in the final minimized DFA, which is really just a large graph.
+
+The algorithms inplemented in L<FLAT> to convert from a PRE to a PFA (equivalent
+to a PetriNet) to a NFA to a DFA, and finally to a minimized DFA are the basic'
+ones discussed in any basic CS text book on automata, e.g., [5].
+
 =head1 SEE ALSO
 
-L<Pipeworks>, L<Sub::Pipeline>, L<Process::Pipeline>, L<FLAT>,
-L<Graph::PetriNet>
+L<Pipeworks>, L<Sub::Pipeline>, L<Process::Pipeline>, L<FLAT>, L<Graph::PetriNet>
 
 =head2 Good Reads
 
@@ -1248,7 +829,7 @@ Same terms as perl itself.
 
 =head1 AUTHOR
 
-OODLER 577 E<lt>oodler@cpan.orgE<gt>
+OODLER 577 <oodler@cpan.org>
 
 =head1 ACKNOWLEDGEMENTS
 
